@@ -1,6 +1,5 @@
-use crate::{Accounts, Sysvar, ToAccountInfo};
+use crate::{Accounts, ToAccountInfo};
 use solana_program::account_info::AccountInfo;
-use solana_program::sysvar::rent::Rent;
 
 /// The Ctor accounts that can be used to create any account within the program
 /// itself (instead of creating the account on the client).
@@ -25,6 +24,4 @@ pub struct Ctor<'info> {
     pub system_program: AccountInfo<'info>,
     // The program whose state is being constructed.
     pub program: AccountInfo<'info>,
-    // Rent sysvar.
-    pub rent: Sysvar<'info, Rent>,
 }
